@@ -16,22 +16,22 @@ use Proc::InvokeEditor;
 #'END_USE
 
 use constant options => (
-	[ 'verbose|v!'       => 'Output progress information' ],
-	[ 'input|i=s'        => 'The summary file to edit' ],
-	[ 'mode'             => hidden => { default => "interactive", one_of => [
+	[ 'verbose|v!'        => 'Output progress information' ],
+	[ 'input|i=s'         => 'The summary file to edit' ],
+	[ 'mode'              => hidden => { default => "interactive", one_of => [
 		[ 'interactive'      => "Edit the file interactively (the default)" ],
-		[ 'save:s'           => "Output a flatfile to a file or STDOUT" ],
-		[ 'load:s'           => "Load the specified file or STDIN into the summary" ],
+		[ 'save'             => "Output a flatfile to a file or STDOUT" ],
+		[ 'load'             => "Load the specified file or STDIN into the summary" ],
 	] } ],
-	[ 'skip|s!'          => 'Skip threads that have already been summarized' ],
-	[ 'hidden|H!'        => 'Include hidden threads' ],
-	[ 'links|l!'         => 'Include links to on-line archives', { default => 1 } ], # TODO shorten
-	[ 'archive|a=s'      => 'The rchive to use (defaults to "google")', { default => "google" } ],
-	[ 'posters|p!'       => 'Include posters names in the comment section', { default => 1 } ],
-	[ 'dates|d!'         => 'Include start and end dates in the comment section', { default => 1 } ],
-	[ 'misc|m!'          => 'Include misc info in the comment section', { default => 1 } ],
-	[ 'extra_field|e=s@' => "Additional fields to include in the YAML header (can be used several times)" ],
-	[ 'pattern|P=s@'     => "Only include summaries matching this regex (matches against formatted text)" ],
+	[ 'skip|s!'           => 'Skip threads that have already been summarized' ],
+	[ 'hidden|H!'         => 'Include hidden threads' ],
+	[ 'links|l!'          => 'Include links to on-line archives', { default => 1 } ], # TODO shorten
+	[ 'archive|a=s'       => 'The rchive to use (defaults to "google")', { default => "google" } ],
+	[ 'posters|p!'        => 'Include posters names in the comment section', { default => 1 } ],
+	[ 'dates|d!'          => 'Include start and end dates in the comment section', { default => 1 } ],
+	[ 'misc|m!'           => 'Include misc info in the comment section', { default => 1 } ],
+	[ 'extra_fields|e=s@' => "Additional fields to include in the YAML header (can be used several times)" ],
+	[ 'pattern|P=s@'      => "Only include summaries matching this regex (matches against formatted text)" ],
 );
 
 sub validate {
@@ -48,20 +48,24 @@ sub validate {
 
 	if ( defined($opt->{load}) and $opt->{load} eq "" || $opt->{load} ) {
 		$self->usage_error("You can choose one and only one of --interactive, --load or --save.") if $opt->{interactive};
-		$opt->{load} ||= \*STDIN;
+		$opt->{load} = \*STDIN;
 		unless ( ref( my $file = $opt->{load} ) ) {
 			open my $in, "<", $file || die "open($file): $!";
 			$opt->{load} = $in;
 		}
+
+		binmode $opt->{load}, ":utf8";
 	}
 	
 	if ( defined($opt->{save}) and $opt->{save} eq "" || $opt->{save} ) {
 		$self->usage_error("You can choose one and only one of --interactive, --load or --save.") if $opt->{load};
-		$opt->{save} ||= \*STDOUT;
+		$opt->{save} = \*STDOUT;
 		unless ( ref( my $file = $opt->{save} ) ) {
 			open my $out, ">", $file || die "open($file): $!";
 			$opt->{save} = $out;
 		}
+
+		binmode $opt->{save}, ":utf8";
 	}
 
 	$self->{opt} = $opt;
@@ -72,11 +76,11 @@ sub load_summary {
 	my $opt = $self->{opt};
 
 	Mail::Summary::Tools::Summary->load(
-        $opt->{input},
-        thread => {
-            default_archive => $opt->{archive},
+		$opt->{input},
+		thread => {
+			default_archive     => $opt->{archive},
 			archive_link_params => { cache => $self->app->context->cache },
-        },
+		},
 	);
 }
 
@@ -92,7 +96,7 @@ sub create_flatfile {
 		list_dates      => $opt->{dates},
 		list_misc       => $opt->{misc},
 		add_links       => $opt->{links},
-		extra_field     => $opt->{extra_field},
+		extra_fields    => [ map { split ',', $_ } @{ $opt->{extra_fields} } ],
 		patterns        => [ map { qr/$_/ } @{ $opt->{pattern} || [] } ],
 	);
 }
@@ -116,8 +120,8 @@ sub run_load {
 
 	my $summary = $self->load_summary;
 	my $flat = $self->create_flatfile( $summary );
-	
-	my $in = $opt->{load};
+
+	my $in = $opt->{load}; # aha
 	my $buffer = do { local $/; <$in> };
 
 	$flat->load($buffer);
